@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  pyScanMaster -- Python Interface to ScanMaster POS
-#  Copyright © 2013 Sacramento Natural Foods Co-op, Inc
+#  Copyright © 2013-2014 Sacramento Natural Foods Co-op, Inc
 #
 #  This file is part of pyScanMaster.
 #
@@ -38,7 +37,8 @@ from decimal import Decimal
 
 
 __all__ = [
-    u'Item', u'Customer', u'NegativeCheck', u'InstoreCharge', u'ChargeHistory',
+    u'Department', u'Item', u'ElectronicCoupon',
+    u'Customer', u'NegativeCheck', u'InstoreCharge', u'ChargeHistory',
     u'EJTransaction', u'EJCustomer', u'EJItem', u'EJPromotion', u'EJDiscount', u'EJTax',
     ]
 
@@ -175,6 +175,79 @@ def time_property(column, fmt):
     return property(getter, setter)
 
 
+class Department(Base):
+    """
+    Represents a department.
+    """
+    __tablename__ = u'Department'
+
+    Department = Column(
+        u'Department', String(length=4), primary_key=True, nullable=False)
+
+    Description = Column(
+        u'Description', String(length=15), nullable=False)
+
+    FoodStamp = Column(
+        u'FoodStamp', String(length=1), nullable=False)
+
+    Tax1 = Column(
+        u'Tax1', String(length=1), nullable=False)
+
+    Tax2 = Column(
+        u'Tax2', String(length=1), nullable=False)
+
+    Tax3 = Column(
+        u'Tax3', String(length=1), nullable=False)
+
+    Discount1 = Column(
+        u'Discount1', String(length=1), nullable=False)
+
+    Discount2 = Column(
+        u'Discount2', String(length=1), nullable=False)
+
+    FrequentShopper = Column(
+        u'FrequentShopper', String(length=1), nullable=False)
+
+    HALO = Column(
+        u'HALO', String(length=6), nullable=False)
+
+    LALO = Column(
+        u'LALO', String(length=6), nullable=False)
+
+    QuantityLimit = Column(
+        u'QuantityLimit', String(length=2), nullable=False)
+
+    GroupLink = Column(
+        u'GroupLink', String(length=2), nullable=False)
+
+    ReceiptCouponNum = Column(
+        u'ReceiptCouponNum', String(length=4), nullable=False)
+
+    CouponUnderOver = Column(
+        u'CouponUnderOver', String(length=1), nullable=False)
+
+    UnderOverAmount = Column(
+        u'UnderOverAmount', String(length=6), nullable=False)
+
+    DepartmentType = Column(
+        u'DepartmentType', String(length=1), nullable=False)
+
+    GLAccountNumber = Column(
+        u'GLAccountNumber', String(length=10), nullable=False)
+
+    ExcludeFromMinPur = Column(
+        u'ExcludeFromMinPur', String(length=1), nullable=False)
+
+    Rx = Column(
+        u'Rx', String(length=1), nullable=False)
+
+    NonRxHC = Column(
+        u'NonRxHC', String(length=1), nullable=False)
+
+    Blanks = Column(
+        u'Blanks', String(length=8), nullable=True)
+
+
 class Item(Base):
     """
     Represents an item (product).
@@ -425,6 +498,151 @@ class Item(Base):
         return unicode(self.POSDescription)
 
 
+class ElectronicCoupon(Base):
+    """
+    Represents an electronic coupon.
+    """
+    __tablename__ = u'ElectronicCoupon'
+
+    Upc = Column(
+        u'Upc', String(length=20), primary_key=True, nullable=False)
+
+    Vendor = Column(
+        u'Vendor', String(length=12), nullable=False)
+
+    Commoditycode = Column(
+        u'Commoditycode', String(length=12), nullable=False)
+
+    Department = Column(
+        u'Department', String(length=4), primary_key=True, nullable=False)
+
+    Reportcode = Column(
+        u'Reportcode', String(length=4), primary_key=True, nullable=False)
+
+    Description = Column(
+        u'Description', String(length=30), nullable=False)
+
+    Coupontype = Column(
+        u'Coupontype', String(length=1), nullable=False)
+
+    Discounttype = Column(
+        u'Discounttype', String(length=1), nullable=False)
+
+    Discount = Column(
+        u'Discount', String(length=6), nullable=False)
+
+    Buys = Column(
+        u'Buys', String(length=6), nullable=False)
+
+    Gets = Column(
+        u'Gets', String(length=6), nullable=False)
+
+    Limitedquantity = Column(
+        u'Limitedquantity', String(length=6), nullable=False)
+
+    Startdate = Column(
+        u'Startdate', String(length=6), nullable=False)
+
+    Starttime = Column(
+        u'Starttime', String(length=4), nullable=False)
+
+    Enddate = Column(
+        u'Enddate', String(length=6), nullable=False)
+
+    Endtime = Column(
+        u'Endtime', String(length=4), nullable=False)
+
+    Points = Column(
+        u'Points', String(length=6), nullable=False)
+
+    Bonus = Column(
+        u'Bonus', String(length=6), nullable=False)
+
+    ReceiptCoupon = Column(
+        u'ReceiptCoupon', String(length=4), nullable=False)
+
+    PromoID = Column(
+        u'PromoID', String(length=20), primary_key=True, nullable=False)
+
+    CEcquantity = Column(
+        u'CEcquantity', String(length=6), nullable=False)
+
+    CEcamount = Column(
+        u'CEcamount', String(length=9), nullable=False)
+
+    CTpoints = Column(
+        u'CTpoints', String(length=12), nullable=False)
+
+    CTbonus = Column(
+        u'CTbonus', String(length=12), nullable=False)
+
+    PECquantity = Column(
+        u'PECquantity', String(length=6), nullable=False)
+
+    PECcamount = Column(
+        u'PECcamount', String(length=9), nullable=False)
+
+    PTpoints = Column(
+        u'PTpoints', String(length=12), nullable=False)
+
+    PTbonus = Column(
+        u'PTbonus', String(length=12), nullable=False)
+
+    CloseDate = Column(
+        u'CloseDate', String(length=6), nullable=False)
+
+    FrequentShopperLevel = Column(
+        u'FrequentShopperLevel', String(length=1), primary_key=True, nullable=False)
+
+    MinPurchase = Column(
+        u'MinPurchase', String(length=7), nullable=False)
+
+    MixMatch = Column(
+        u'MixMatch', String(length=4), primary_key=True, nullable=False)
+
+    TotalSale = Column(
+        u'TotalSale', String(length=7), primary_key=True, nullable=False)
+
+    DepartmentTotal = Column(
+        u'DepartmentTotal', String(length=7), nullable=False)
+
+    SortDepartment = Column(
+        u'SortDepartment', String(length=4), nullable=False)
+
+    RedeemValue = Column(
+        u'RedeemValue', String(length=6), nullable=False)
+
+    BundleCode = Column(
+        u'BundleCode', String(length=2), primary_key=True, nullable=False)
+
+    Weighted = Column(
+        u'Weighted', String(length=1), nullable=False)
+
+    FavorFlag = Column(
+        u'FavorFlag', String(length=1), nullable=False)
+
+    Mediafile = Column(
+        u'Mediafile', String(length=35), nullable=False)
+
+    UCIPromoID = Column(
+        u'UCIPromoID', String(length=20), nullable=False)
+
+    Unused = Column(
+        u'Unused', String(length=10), nullable=False)
+
+    MMCurrentQuantity = Column(
+        u'MMCurrentQuantity', String(length=6), nullable=False)
+
+    MMPTDQuantity = Column(
+        u'MMPTDQuantity', String(length=6), nullable=False)
+
+    MinimumQty = Column(
+        u'MinimumQty', String(length=6), nullable=False)
+
+    Blanks = Column(
+        u'Blanks', String(length=98), nullable=True)
+
+
 class Customer(Base):
     """
     Represents a customer.
